[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[vidalia-svn] r1547: Add a column to the list of servers, with a little flag icon (in trunk: . src/gui/network src/gui/res src/gui/res/flags)



Author: edmanm
Date: 2006-12-23 01:53:57 -0500 (Sat, 23 Dec 2006)
New Revision: 1547

Added:
   trunk/src/gui/res/flags/ae.png
   trunk/src/gui/res/flags/af.png
   trunk/src/gui/res/flags/al.png
   trunk/src/gui/res/flags/am.png
   trunk/src/gui/res/flags/an.png
   trunk/src/gui/res/flags/ao.png
   trunk/src/gui/res/flags/ar.png
   trunk/src/gui/res/flags/at.png
   trunk/src/gui/res/flags/au.png
   trunk/src/gui/res/flags/aw.png
   trunk/src/gui/res/flags/az.png
   trunk/src/gui/res/flags/ba.png
   trunk/src/gui/res/flags/bb.png
   trunk/src/gui/res/flags/bd.png
   trunk/src/gui/res/flags/be.png
   trunk/src/gui/res/flags/bf.png
   trunk/src/gui/res/flags/bh.png
   trunk/src/gui/res/flags/bi.png
   trunk/src/gui/res/flags/bj.png
   trunk/src/gui/res/flags/bm.png
   trunk/src/gui/res/flags/bn.png
   trunk/src/gui/res/flags/bo.png
   trunk/src/gui/res/flags/br.png
   trunk/src/gui/res/flags/bs.png
   trunk/src/gui/res/flags/bt.png
   trunk/src/gui/res/flags/bw.png
   trunk/src/gui/res/flags/by.png
   trunk/src/gui/res/flags/bz.png
   trunk/src/gui/res/flags/ca.png
   trunk/src/gui/res/flags/cf.png
   trunk/src/gui/res/flags/cg.png
   trunk/src/gui/res/flags/ch.png
   trunk/src/gui/res/flags/ci.png
   trunk/src/gui/res/flags/ck.png
   trunk/src/gui/res/flags/cl.png
   trunk/src/gui/res/flags/cm.png
   trunk/src/gui/res/flags/cn.png
   trunk/src/gui/res/flags/co.png
   trunk/src/gui/res/flags/cr.png
   trunk/src/gui/res/flags/cs.png
   trunk/src/gui/res/flags/cu.png
   trunk/src/gui/res/flags/cv.png
   trunk/src/gui/res/flags/cy.png
   trunk/src/gui/res/flags/cz.png
   trunk/src/gui/res/flags/dk.png
   trunk/src/gui/res/flags/dz.png
   trunk/src/gui/res/flags/ec.png
   trunk/src/gui/res/flags/ee.png
   trunk/src/gui/res/flags/eg.png
   trunk/src/gui/res/flags/er.png
   trunk/src/gui/res/flags/et.png
   trunk/src/gui/res/flags/fj.png
   trunk/src/gui/res/flags/fo.png
   trunk/src/gui/res/flags/ga.png
   trunk/src/gui/res/flags/gb.png
   trunk/src/gui/res/flags/ge.png
   trunk/src/gui/res/flags/gi.png
   trunk/src/gui/res/flags/gl.png
   trunk/src/gui/res/flags/gp.png
   trunk/src/gui/res/flags/gr.png
   trunk/src/gui/res/flags/gt.png
   trunk/src/gui/res/flags/gu.png
   trunk/src/gui/res/flags/gy.png
   trunk/src/gui/res/flags/hk.png
   trunk/src/gui/res/flags/hr.png
   trunk/src/gui/res/flags/ht.png
   trunk/src/gui/res/flags/id.png
   trunk/src/gui/res/flags/ie.png
   trunk/src/gui/res/flags/il.png
   trunk/src/gui/res/flags/in.png
   trunk/src/gui/res/flags/iq.png
   trunk/src/gui/res/flags/ir.png
   trunk/src/gui/res/flags/is.png
   trunk/src/gui/res/flags/jm.png
   trunk/src/gui/res/flags/jo.png
   trunk/src/gui/res/flags/jp.png
   trunk/src/gui/res/flags/ke.png
   trunk/src/gui/res/flags/kg.png
   trunk/src/gui/res/flags/kh.png
   trunk/src/gui/res/flags/ki.png
   trunk/src/gui/res/flags/kp.png
   trunk/src/gui/res/flags/kr.png
   trunk/src/gui/res/flags/kw.png
   trunk/src/gui/res/flags/ky.png
   trunk/src/gui/res/flags/kz.png
   trunk/src/gui/res/flags/lb.png
   trunk/src/gui/res/flags/lc.png
   trunk/src/gui/res/flags/lk.png
   trunk/src/gui/res/flags/lt.png
   trunk/src/gui/res/flags/lu.png
   trunk/src/gui/res/flags/lv.png
   trunk/src/gui/res/flags/ly.png
   trunk/src/gui/res/flags/ma.png
   trunk/src/gui/res/flags/mc.png
   trunk/src/gui/res/flags/md.png
   trunk/src/gui/res/flags/mg.png
   trunk/src/gui/res/flags/mk.png
   trunk/src/gui/res/flags/mn.png
   trunk/src/gui/res/flags/mo.png
   trunk/src/gui/res/flags/mp.png
   trunk/src/gui/res/flags/ms.png
   trunk/src/gui/res/flags/mt.png
   trunk/src/gui/res/flags/mx.png
   trunk/src/gui/res/flags/my.png
   trunk/src/gui/res/flags/mz.png
   trunk/src/gui/res/flags/na.png
   trunk/src/gui/res/flags/nc.png
   trunk/src/gui/res/flags/nf.png
   trunk/src/gui/res/flags/no.png
   trunk/src/gui/res/flags/np.png
   trunk/src/gui/res/flags/nr.png
   trunk/src/gui/res/flags/nz.png
   trunk/src/gui/res/flags/om.png
   trunk/src/gui/res/flags/pa.png
   trunk/src/gui/res/flags/pe.png
   trunk/src/gui/res/flags/pf.png
   trunk/src/gui/res/flags/ph.png
   trunk/src/gui/res/flags/pk.png
   trunk/src/gui/res/flags/pm.png
   trunk/src/gui/res/flags/pr.png
   trunk/src/gui/res/flags/py.png
   trunk/src/gui/res/flags/qa.png
   trunk/src/gui/res/flags/ro.png
   trunk/src/gui/res/flags/sa.png
   trunk/src/gui/res/flags/sb.png
   trunk/src/gui/res/flags/sd.png
   trunk/src/gui/res/flags/se.png
   trunk/src/gui/res/flags/sg.png
   trunk/src/gui/res/flags/si.png
   trunk/src/gui/res/flags/sk.png
   trunk/src/gui/res/flags/sl.png
   trunk/src/gui/res/flags/sm.png
   trunk/src/gui/res/flags/so.png
   trunk/src/gui/res/flags/sy.png
   trunk/src/gui/res/flags/tc.png
   trunk/src/gui/res/flags/tg.png
   trunk/src/gui/res/flags/th.png
   trunk/src/gui/res/flags/tn.png
   trunk/src/gui/res/flags/to.png
   trunk/src/gui/res/flags/tp.png
   trunk/src/gui/res/flags/tr.png
   trunk/src/gui/res/flags/tt.png
   trunk/src/gui/res/flags/tv.png
   trunk/src/gui/res/flags/tw.png
   trunk/src/gui/res/flags/tz.png
   trunk/src/gui/res/flags/ua.png
   trunk/src/gui/res/flags/ug.png
   trunk/src/gui/res/flags/unknown.png
   trunk/src/gui/res/flags/us.png
   trunk/src/gui/res/flags/uy.png
   trunk/src/gui/res/flags/va.png
   trunk/src/gui/res/flags/ve.png
   trunk/src/gui/res/flags/vg.png
   trunk/src/gui/res/flags/vi.png
   trunk/src/gui/res/flags/vn.png
   trunk/src/gui/res/flags/ws.png
   trunk/src/gui/res/flags/ye.png
   trunk/src/gui/res/flags/za.png
   trunk/src/gui/res/flags/zw.png
Modified:
   trunk/AUTHORS
   trunk/src/gui/network/netviewer.cpp
   trunk/src/gui/network/netviewer.ui
   trunk/src/gui/network/routerlistitem.cpp
   trunk/src/gui/network/routerlistitem.h
   trunk/src/gui/network/routerlistwidget.cpp
   trunk/src/gui/network/routerlistwidget.h
   trunk/src/gui/res/flags/bg.png
   trunk/src/gui/res/flags/de.png
   trunk/src/gui/res/flags/en.png
   trunk/src/gui/res/flags/es.png
   trunk/src/gui/res/flags/fa.png
   trunk/src/gui/res/flags/fi.png
   trunk/src/gui/res/flags/fr.png
   trunk/src/gui/res/flags/hu.png
   trunk/src/gui/res/flags/it.png
   trunk/src/gui/res/flags/nb.png
   trunk/src/gui/res/flags/nl.png
   trunk/src/gui/res/flags/pl.png
   trunk/src/gui/res/flags/pt.png
   trunk/src/gui/res/flags/ru.png
   trunk/src/gui/res/flags/zh-cn.png
   trunk/src/gui/res/vidalia_common.qrc
Log:
Add a column to the list of servers, with a little flag icon for each server.


Modified: trunk/AUTHORS
===================================================================
--- trunk/AUTHORS	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/AUTHORS	2006-12-23 06:53:57 UTC (rev 1547)
@@ -25,8 +25,8 @@
 
   Geoff Goodell <http://afs.eecs.harvard.edu/~goodell/> supplied us with
   nearly all of the flag icons that we use in the Appearance configuration
-  page. He also created the router status icons we use in the network view
-  dialog.
+  page and network map. He also created the router status icons we use in 
+  the network map.
 
   Michael Zuercher and Adam Tomjack of Zuerchertech LLC
   <http://www.zuerchertech.com> gave us the ZImageView class which handles

Modified: trunk/src/gui/network/netviewer.cpp
===================================================================
--- trunk/src/gui/network/netviewer.cpp	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/network/netviewer.cpp	2006-12-23 06:53:57 UTC (rev 1547)
@@ -67,8 +67,9 @@
   
   /* Change the column widths of the tree widgets */
   ui.treeRouterList->header()->
-    resizeSection(RouterListWidget::StatusColumn,
-		  RouterListWidget::StatusColumnWidth);
+    resizeSection(RouterListWidget::StatusColumn, 25);
+  ui.treeRouterList->header()->
+    resizeSection(RouterListWidget::CountryColumn, 25);
   ui.treeCircuitList->header()->
     resizeSection(CircuitListWidget::ConnectionColumn,
 		  CircuitListWidget::ConnectionColumnWidth);
@@ -231,7 +232,7 @@
     ui.treeCircuitList->addStream(stream);
   }
 
-  /** Update the map */
+  /* Update the map */
   _map->update();
 }
 
@@ -398,7 +399,7 @@
       router = ui.treeRouterList->findRouterById(id);
       if (router) {
         /* Save the location information in the descriptor */
-        router->setLocation(geoip.toLocation());
+        router->setLocation(geoip);
         /* Plot the router on the map */
         _map->addRouter(router->id(), geoip.latitude(), geoip.longitude());
       }

Modified: trunk/src/gui/network/netviewer.ui
===================================================================
--- trunk/src/gui/network/netviewer.ui	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/network/netviewer.ui	2006-12-23 06:53:57 UTC (rev 1547)
@@ -332,7 +332,7 @@
        </property>
        <property name="minimumSize" >
         <size>
-         <width>150</width>
+         <width>175</width>
          <height>0</height>
         </size>
        </property>
@@ -345,6 +345,9 @@
        <property name="sortingEnabled" >
         <bool>true</bool>
        </property>
+       <property name="indentation" >
+        <number>0</number> 
+       </property>
       </widget>
       <widget class="QSplitter" name="splitter3" >
        <property name="sizePolicy" >

Modified: trunk/src/gui/network/routerlistitem.cpp
===================================================================
--- trunk/src/gui/network/routerlistitem.h	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/network/routerlistitem.h	2006-12-23 06:53:57 UTC (rev 1547)
@@ -32,6 +32,7 @@
 #include <QTreeWidgetItem>
 #include <QString>
 #include <control/routerdescriptor.h>
+#include <util/geoip/geoip.h>
 
 #include "routerlistwidget.h"
 
@@ -57,7 +58,7 @@
   /** Returns the descriptor for this router. */
   RouterDescriptor descriptor() const { return *_rd; }
   /** Sets the location information for this router item. */
-  void setLocation(QString location);
+  void setLocation(GeoIp geoip);
 
   /** Overload the comparison operator. */
   virtual bool operator<(const QTreeWidgetItem &other) const;
@@ -66,6 +67,8 @@
   RouterDescriptor* _rd;   /**< Descriptor for this router item. */
   RouterListWidget* _list; /**< The list for this list item. */
   qint64 _statusValue;     /**< Value used to sort items by status. */
+  QString _country;        /**< Country in which this router is likely
+                                located. */
 };
 
 #endif

Modified: trunk/src/gui/network/routerlistwidget.cpp
===================================================================
--- trunk/src/gui/network/routerlistwidget.cpp	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/network/routerlistwidget.cpp	2006-12-23 06:53:57 UTC (rev 1547)
@@ -37,7 +37,9 @@
 : QTreeWidget(parent)
 {
   /* Create and initialize columns */
-  setHeaderLabels(QStringList() << tr("Status") << tr("Server"));
+  setHeaderLabels(QStringList() << QString("")
+                                << QString("")
+                                << tr("Server"));
 
   /* Sort by descending server bandwidth */
   sortItems(StatusColumn, Qt::DescendingOrder);
@@ -228,6 +230,6 @@
   if (items.count() > 0) {
       rd = ((RouterListItem *)items[0])->descriptor();
   }
-    emit routerSelected(rd);
+  emit routerSelected(rd);
 }
 

Modified: trunk/src/gui/network/routerlistwidget.h
===================================================================
--- trunk/src/gui/network/routerlistwidget.h	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/network/routerlistwidget.h	2006-12-23 06:53:57 UTC (rev 1547)
@@ -47,14 +47,11 @@
 public:
   /** Columns in the list. */
   enum Columns {
-    StatusColumn = 0,  /**< Status column, indicating bandwidth */
-    NameColumn = 1,    /*< Router's name. */
+    StatusColumn  = 0,  /**< Status column, indicating bandwidth. */
+    CountryColumn = 1,  /**< Router's country flag. */
+    NameColumn    = 2,  /**< Router's name. */
     
   };
-  /** Column widths. */
-  enum ColumnWidths {
-    StatusColumnWidth = 55 /**< Initial width of the status column. */
-  };
 
   /** Default constructor. */
   RouterListWidget(QWidget *parent = 0);

Added: trunk/src/gui/res/flags/ae.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ae.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/af.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/af.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/al.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/al.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/am.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/am.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/an.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/an.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ao.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ao.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ar.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ar.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/at.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/at.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/au.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/au.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/aw.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/aw.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/az.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/az.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ba.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ba.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bb.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bb.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bd.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bd.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/be.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/be.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bf.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bf.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/bg.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/bh.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bh.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bi.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bi.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bj.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bj.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bm.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bm.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bn.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bn.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bo.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bo.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/br.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/br.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bs.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bs.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bt.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bt.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bw.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bw.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/by.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/by.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/bz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/bz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ca.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ca.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cf.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cf.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ch.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ch.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ci.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ci.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ck.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ck.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cl.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cl.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cm.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cm.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cn.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cn.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/co.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/co.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cs.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cs.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cu.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cu.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cv.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cv.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cy.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cy.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/cz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/cz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/de.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/dk.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/dk.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/dz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/dz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ec.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ec.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ee.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ee.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/eg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/eg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/en.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/er.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/er.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/es.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/et.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/et.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/fa.png
===================================================================
(Binary files differ)

Modified: trunk/src/gui/res/flags/fi.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/fj.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/fj.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/fo.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/fo.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/fr.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/ga.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ga.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gb.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gb.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ge.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ge.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gi.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gi.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gl.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gl.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gp.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gp.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gt.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gt.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gu.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gu.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/gy.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/gy.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/hk.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/hk.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/hr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/hr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ht.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ht.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/hu.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/id.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/id.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ie.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ie.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/il.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/il.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/in.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/in.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/iq.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/iq.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ir.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ir.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/is.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/is.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/it.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/jm.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/jm.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/jo.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/jo.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/jp.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/jp.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ke.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ke.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/kg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/kg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/kh.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/kh.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ki.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ki.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/kp.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/kp.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/kr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/kr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/kw.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/kw.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ky.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ky.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/kz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/kz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/lb.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/lb.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/lc.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/lc.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/lk.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/lk.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/lt.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/lt.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/lu.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/lu.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/lv.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/lv.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ly.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ly.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ma.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ma.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mc.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mc.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/md.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/md.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mk.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mk.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mn.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mn.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mo.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mo.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mp.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mp.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ms.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ms.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mt.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mt.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mx.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mx.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/my.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/my.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/mz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/mz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/na.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/na.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/nb.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/nc.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/nc.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/nf.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/nf.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/nl.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/no.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/no.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/np.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/np.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/nr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/nr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/nz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/nz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/om.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/om.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/pa.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/pa.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/pe.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/pe.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/pf.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/pf.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ph.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ph.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/pk.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/pk.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/pl.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/pm.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/pm.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/pr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/pr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/pt.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/py.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/py.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/qa.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/qa.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ro.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ro.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/ru.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/sa.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sa.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sb.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sb.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sd.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sd.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/se.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/se.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/si.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/si.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sk.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sk.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sl.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sl.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sm.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sm.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/so.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/so.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/sy.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/sy.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tc.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tc.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/th.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/th.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tn.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tn.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/to.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/to.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tp.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tp.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tr.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tr.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tt.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tt.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tv.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tv.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tw.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tw.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/tz.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/tz.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ua.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ua.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ug.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ug.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/unknown.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/unknown.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/us.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/us.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/uy.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/uy.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/va.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/va.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ve.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ve.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/vg.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/vg.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/vi.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/vi.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/vn.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/vn.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ws.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ws.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/ye.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/ye.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Added: trunk/src/gui/res/flags/za.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/za.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/flags/zh-cn.png
===================================================================
(Binary files differ)

Added: trunk/src/gui/res/flags/zw.png
===================================================================
(Binary files differ)


Property changes on: trunk/src/gui/res/flags/zw.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Modified: trunk/src/gui/res/vidalia_common.qrc
===================================================================
--- trunk/src/gui/res/vidalia_common.qrc	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/res/vidalia_common.qrc	2006-12-23 06:53:57 UTC (rev 1547)
@@ -78,21 +78,180 @@
         <file>icons/node-bw-high.png</file>
     </qresource>
     <qresource prefix="/images">
+        <file>flags/ae.png</file>
+        <file>flags/af.png</file>
+        <file>flags/al.png</file>
+        <file>flags/am.png</file>
+        <file>flags/an.png</file>
+        <file>flags/ao.png</file>
+        <file>flags/ar.png</file>
+        <file>flags/at.png</file>
+        <file>flags/au.png</file>
+        <file>flags/aw.png</file>
+        <file>flags/az.png</file>
+        <file>flags/ba.png</file>
+        <file>flags/bb.png</file>
+        <file>flags/bd.png</file>
+        <file>flags/be.png</file>
+        <file>flags/bf.png</file>
         <file>flags/bg.png</file>
+        <file>flags/bh.png</file>
+        <file>flags/bi.png</file>
+        <file>flags/bj.png</file>
+        <file>flags/bm.png</file>
+        <file>flags/bn.png</file>
+        <file>flags/bo.png</file>
+        <file>flags/br.png</file>
+        <file>flags/bs.png</file>
+        <file>flags/bt.png</file>
+        <file>flags/bw.png</file>
+        <file>flags/by.png</file>
+        <file>flags/bz.png</file>
+        <file>flags/ca.png</file>
+        <file>flags/cf.png</file>
+        <file>flags/cg.png</file>
+        <file>flags/ch.png</file>
+        <file>flags/ci.png</file>
+        <file>flags/ck.png</file>
+        <file>flags/cl.png</file>
+        <file>flags/cm.png</file>
+        <file>flags/cn.png</file>
+        <file>flags/co.png</file>
+        <file>flags/cr.png</file>
+        <file>flags/cs.png</file>
+        <file>flags/cu.png</file>
+        <file>flags/cv.png</file>
+        <file>flags/cy.png</file>
+        <file>flags/cz.png</file>
         <file>flags/de.png</file>
+        <file>flags/dk.png</file>
+        <file>flags/dz.png</file>
+        <file>flags/ec.png</file>
+        <file>flags/ee.png</file>
+        <file>flags/eg.png</file>
         <file>flags/en.png</file>
+        <file>flags/er.png</file>
         <file>flags/es.png</file>
+        <file>flags/et.png</file>
         <file>flags/fa.png</file>
         <file>flags/fi.png</file>
+        <file>flags/fj.png</file>
+        <file>flags/fo.png</file>
         <file>flags/fr.png</file>
+        <file>flags/ga.png</file>
+        <file>flags/gb.png</file>
+        <file>flags/ge.png</file>
+        <file>flags/gi.png</file>
+        <file>flags/gl.png</file>
+        <file>flags/gp.png</file>
+        <file>flags/gr.png</file>
+        <file>flags/gt.png</file>
+        <file>flags/gu.png</file>
+        <file>flags/gy.png</file>
+        <file>flags/hk.png</file>
+        <file>flags/hr.png</file>
+        <file>flags/ht.png</file>
         <file>flags/hu.png</file>
+        <file>flags/id.png</file>
+        <file>flags/ie.png</file>
+        <file>flags/il.png</file>
+        <file>flags/in.png</file>
+        <file>flags/iq.png</file>
+        <file>flags/ir.png</file>
+        <file>flags/is.png</file>
         <file>flags/it.png</file>
+        <file>flags/jm.png</file>
+        <file>flags/jo.png</file>
+        <file>flags/jp.png</file>
+        <file>flags/ke.png</file>
+        <file>flags/kg.png</file>
+        <file>flags/kh.png</file>
+        <file>flags/ki.png</file>
+        <file>flags/kp.png</file>
+        <file>flags/kr.png</file>
+        <file>flags/kw.png</file>
+        <file>flags/ky.png</file>
+        <file>flags/kz.png</file>
+        <file>flags/lb.png</file>
+        <file>flags/lc.png</file>
+        <file>flags/lk.png</file>
+        <file>flags/lt.png</file>
+        <file>flags/lu.png</file>
+        <file>flags/lv.png</file>
+        <file>flags/ly.png</file>
+        <file>flags/ma.png</file>
+        <file>flags/mc.png</file>
+        <file>flags/md.png</file>
+        <file>flags/mg.png</file>
+        <file>flags/mk.png</file>
+        <file>flags/mn.png</file>
+        <file>flags/mo.png</file>
+        <file>flags/mp.png</file>
+        <file>flags/ms.png</file>
+        <file>flags/mt.png</file>
+        <file>flags/mx.png</file>
+        <file>flags/my.png</file>
+        <file>flags/mz.png</file>
+        <file>flags/na.png</file>
         <file>flags/nb.png</file>
+        <file>flags/nc.png</file>
+        <file>flags/nf.png</file>
         <file>flags/nl.png</file>
+        <file>flags/no.png</file>
+        <file>flags/np.png</file>
+        <file>flags/nr.png</file>
+        <file>flags/nz.png</file>
+        <file>flags/om.png</file>
+        <file>flags/pa.png</file>
+        <file>flags/pe.png</file>
+        <file>flags/pf.png</file>
+        <file>flags/ph.png</file>
+        <file>flags/pk.png</file>
         <file>flags/pl.png</file>
+        <file>flags/pm.png</file>
+        <file>flags/pr.png</file>
         <file>flags/pt.png</file>
+        <file>flags/py.png</file>
+        <file>flags/qa.png</file>
+        <file>flags/ro.png</file>
         <file>flags/ru.png</file>
+        <file>flags/sa.png</file>
+        <file>flags/sb.png</file>
+        <file>flags/sd.png</file>
+        <file>flags/se.png</file>
+        <file>flags/sg.png</file>
+        <file>flags/si.png</file>
+        <file>flags/sk.png</file>
+        <file>flags/sl.png</file>
+        <file>flags/sm.png</file>
+        <file>flags/so.png</file>
+        <file>flags/sy.png</file>
+        <file>flags/tc.png</file>
+        <file>flags/tg.png</file>
+        <file>flags/th.png</file>
+        <file>flags/tn.png</file>
+        <file>flags/to.png</file>
+        <file>flags/tp.png</file>
+        <file>flags/tr.png</file>
+        <file>flags/tt.png</file>
+        <file>flags/tv.png</file>
+        <file>flags/tw.png</file>
+        <file>flags/tz.png</file>
+        <file>flags/ua.png</file>
+        <file>flags/ug.png</file>
+        <file>flags/us.png</file>
+        <file>flags/uy.png</file>
+        <file>flags/va.png</file>
+        <file>flags/ve.png</file>
+        <file>flags/vg.png</file>
+        <file>flags/vi.png</file>
+        <file>flags/vn.png</file>
+        <file>flags/ws.png</file>
+        <file>flags/ye.png</file>
+        <file>flags/za.png</file>
         <file>flags/zh-cn.png</file>
+        <file>flags/zw.png</file>
+        <file>flags/unknown.png</file>
     </qresource>
     <qresource prefix="/images">
         <file>map/world-map.png</file>
--- trunk/src/gui/network/routerlistitem.cpp	2006-12-22 18:59:47 UTC (rev 1546)
+++ trunk/src/gui/network/routerlistitem.cpp	2006-12-23 06:53:57 UTC (rev 1547)
@@ -25,11 +25,14 @@
  * \brief Item representing a single router and status in a RouterListWidget
  */
 
+#include <QHeaderView>
+
 #include "routerlistwidget.h"
 #include "routerlistitem.h"
 
-#define STATUS_COLUMN (RouterListWidget::StatusColumn)
-#define NAME_COLUMN   (RouterListWidget::NameColumn)
+#define STATUS_COLUMN   (RouterListWidget::StatusColumn)
+#define COUNTRY_COLUMN  (RouterListWidget::CountryColumn)
+#define NAME_COLUMN     (RouterListWidget::NameColumn)
 
 #define IMG_NODE_OFFLINE    ":/images/icons/node-unresponsive.png"
 #define IMG_NODE_SLEEPING   ":/images/icons/node-hibernating.png"
@@ -37,6 +40,7 @@
 #define IMG_NODE_LOW_BW     ":/images/icons/node-bw-low.png"
 #define IMG_NODE_MED_BW     ":/images/icons/node-bw-med.png"
 #define IMG_NODE_HIGH_BW    ":/images/icons/node-bw-high.png"
+#define IMG_FLAG_UNKNOWN    ":/images/flags/unknown.png"
 
 
 /** Default constructor. */
@@ -45,13 +49,16 @@
 {
   _list = list;
   _rd   = 0;
+  _country = "~"; /* Force items with no country to the bottom */
+  setIcon(COUNTRY_COLUMN, QIcon(IMG_FLAG_UNKNOWN));
   update(rd);
 }
 
 /** Destructor. */
 RouterListItem::~RouterListItem()
 {
-  delete _rd;
+  if (_rd)
+    delete _rd;
 }
 
 /** Updates the router descriptor for this item. */
@@ -95,9 +102,18 @@
 
 /** Sets the location information for this item's router descriptor. */
 void
-RouterListItem::setLocation(QString location)
+RouterListItem::setLocation(GeoIp geoip)
 {
-  _rd->setLocation(location);
+  _country = geoip.country().toLower();
+
+  QPixmap flag(":/images/flags/" + _country + ".png");
+  if (!flag.isNull()) {
+    setIcon(COUNTRY_COLUMN, QIcon(flag));
+  }
+  setToolTip(COUNTRY_COLUMN, geoip.toLocation());
+  
+  if (_rd)
+    _rd->setLocation(geoip.toLocation());
 }
 
 /** Overload the comparison operator. */
@@ -106,14 +122,39 @@
 {
   const RouterListItem *a = this;
   const RouterListItem *b = (RouterListItem *)&other;
-
+ 
   if (_list) {
-    if (_list->sortColumn() == RouterListWidget::StatusColumn) {
-      /* Numeric comparison based on status and/or bandwidth */
-      return (a->_statusValue < b->_statusValue);
-    } else if (_list->sortColumn() == RouterListWidget::NameColumn) {
-      /* Perform a case-insensitive comparison based on router name */
-      return (a->name().toLower() < b->name().toLower());
+    Qt::SortOrder order = _list->header()->sortIndicatorOrder();
+    switch (_list->sortColumn()) {
+      case RouterListWidget::StatusColumn:
+        /* Numeric comparison based on status and/or bandwidth */
+        if (a->_statusValue == b->_statusValue) {
+          if (order == Qt::AscendingOrder)
+            return (a->name().toLower() > b->name().toLower());
+          else
+            return (a->name().toLower() < b->name().toLower());
+        }
+        return (a->_statusValue < b->_statusValue);
+      case RouterListWidget::CountryColumn:
+        /* Compare based on country code */
+        if (a->_country == b->_country) {
+          if (order == Qt::AscendingOrder)
+            return (a->_statusValue > b->_statusValue);
+          else
+            return (a->_statusValue < b->_statusValue);
+        }
+        return (a->_country < b->_country);
+      case RouterListWidget::NameColumn:
+        /* Case-insensitive comparison based on router name */
+        if (a->name().toLower() == b->name().toLower()) {
+          if (order == Qt::AscendingOrder)
+            return (a->_statusValue > b->_statusValue);
+          else
+            return (a->_statusValue < b->_statusValue);
+        }
+        return (a->name().toLower() < b->name().toLower());
+      default:
+        break;
     }
   }
   return QTreeWidgetItem::operator<(other);

Modified: trunk/src/gui/network/routerlistitem.h
===================================================================